@@ -715,7 +715,14 @@ static int checker_validate_lists (struct definition_t * root)
                                  !strcmp (def->type, "AC") ||
                                  !strcmp (def->type, "SP")))
         {
-            struct value_t * val = checker_find_reference (def, "Type");
+            struct value_t * val;
+            if((val = checker_find_reference (def, "Type")) == NULL) {
+                logprint (LOG_ERROR, "line %d: checker error, required property "
+                          "`%s' is invalid in `%s:%s'\n", def->line, "Type",
+                          def->type, def->instance);
+                errors++;
+                continue;
+            }
             char * type = val->ident;
             // list of constant values and constant values
             if (type && (!strcmp (type, "const") || !strcmp (type, "list")))
@@ -888,7 +895,7 @@ static int checker_validate_strips (struct definition_t * root)
         if (!def->action)
         {
             /* find components with substrate property */
-            if (checker_is_property (def->define, "Subst") == PROP_STR)
+            if (def->define && (checker_is_property (def->define, "Subst") == PROP_STR))
             {
                 /* check validity of 'Subst' property */
                 if ((val = checker_validate_reference (def, "Subst")) == NULL)
@@ -942,7 +949,7 @@ static int checker_count_nodesets (struct definition_t * root, char * n)
     int count = 0;
     for (struct definition_t * def = root; def != NULL; def = def->next)
     {
-        if (def->nodeset && !def->duplicate)
+        if (def->nodeset && !def->duplicate && def->nodes)
         {
             char * node = def->nodes->node;
             if (!strcmp (node, n))
@@ -1391,7 +1398,7 @@ static void checker_cleanup_xlat_nodes (struct definition_t * sub)
 {
     for (struct node_t * n = sub->nodes; n != NULL; n = n->next)
     {
-        if (n->xlate) free (n->xlate);
+        free (n->xlate);
         n->xlate = NULL;
         n->xlatenr = 0;
     }
@@ -1500,7 +1507,7 @@ checker_copy_subcircuits (struct definition_t * type,
 
     // create environment for subcircuit instance
     environment * child = new environment (*(type->env));
-    parent->addChild (child);
+    parent->push_front_Child (child);
 
     // put instance properties into subcircuit environment
     for (struct pair_t * pair = inst->pairs; pair != NULL; pair = pair->next)
@@ -1586,7 +1593,7 @@ checker_copy_subcircuits (struct definition_t * type,
     icopy->append (type->instance);
     icopy->append (*(instances));
     icopy->append (inst->instance);
-    child->setName (icopy->toString ("."));
+    child->setName (std::string(icopy->toString (".")));
     delete icopy;
 
     return root;
@@ -1895,9 +1902,9 @@ static void netlist_free_nodes (struct node_t * node)
 /* The following function free()'s the given value. */
 static void netlist_free_value (struct value_t * value)
 {
-    if (value->ident) free (value->ident);
+    free (value->ident);
     if (value->unit)  free (value->unit);
-    if (value->scale) free (value->scale);
+    free (value->scale);
     free (value);
 }
 
@@ -1924,7 +1931,7 @@ static void netlist_free_definition (struct definition_t * def)
 {
     netlist_free_nodes (def->nodes);
     if (!def->copy) netlist_free_pairs (def->pairs);
-    if (def->subcircuit) free (def->subcircuit);
+    free (def->subcircuit);
     free (def->type);
     free (def->instance);
     free (def);
@@ -2281,7 +2288,7 @@ int netlist_checker (environment * env)
         def->sub = checker_build_equations (def->sub, &eqns);
         // setup the subcircuit environment
         environment * subenv = new environment (def->instance);
-        env_root->addChild (subenv);
+        env_root->push_front_Child (subenv);
         checker_setup_env (def, subenv, eqns);
         if (def->sub) def->sub->env = subenv;
         // add subcircuit parameters to equations
