@@ -63,12 +63,12 @@ matrix mosfet::calcMatrixY (nr_double_t frequency) {
   nr_double_t gmb = getOperatingPoint ("gmb");
 
   // compute the models admittances
-  nr_complex_t Ygd = nr_complex_t (0.0, 2.0 * M_PI * frequency * Cgd);
-  nr_complex_t Ygs = nr_complex_t (0.0, 2.0 * M_PI * frequency * Cgs);
+  nr_complex_t Ygd = nr_complex_t (0.0, 2.0 * pi * frequency * Cgd);
+  nr_complex_t Ygs = nr_complex_t (0.0, 2.0 * pi * frequency * Cgs);
   nr_complex_t Yds = gds;
-  nr_complex_t Ybd = nr_complex_t (gbd, 2.0 * M_PI * frequency * Cbd);
-  nr_complex_t Ybs = nr_complex_t (gbs, 2.0 * M_PI * frequency * Cbs);
-  nr_complex_t Ygb = nr_complex_t (0.0, 2.0 * M_PI * frequency * Cgb);
+  nr_complex_t Ybd = nr_complex_t (gbd, 2.0 * pi * frequency * Cbd);
+  nr_complex_t Ybs = nr_complex_t (gbs, 2.0 * pi * frequency * Cbs);
+  nr_complex_t Ygb = nr_complex_t (0.0, 2.0 * pi * frequency * Cgb);
 
   // build admittance matrix and convert it to S-parameter matrix
   matrix y (4);
@@ -107,7 +107,7 @@ matrix mosfet::calcMatrixCy (nr_double_t frequency) {
 
   /* compute channel noise and flicker noise generated by the DC
      transconductance and current flow from drain to source */
-  nr_double_t i = 8 * kelvin (T) / T0 * gm / 3 +
+  nr_double_t i = 8 * celsius2kelvin (T) / T0 * gm / 3 +
     Kf * qucs::pow (Ids, Af) / qucs::pow (frequency, Ffe) / kB / T0;
 
   /* build noise current correlation matrix and convert it to
@@ -191,11 +191,11 @@ void mosfet::initModel (void) {
 
   // get device temperature
   nr_double_t T  = getPropertyDouble ("Temp");
-  nr_double_t T2 = kelvin (getPropertyDouble ("Temp"));
-  nr_double_t T1 = kelvin (getPropertyDouble ("Tnom"));
+  nr_double_t T2 = celsius2kelvin (getPropertyDouble ("Temp"));
+  nr_double_t T1 = celsius2kelvin (getPropertyDouble ("Tnom"));
 
   // apply polarity of MOSFET
-  char * type = getPropertyString ("Type");
+  const char * const type = getPropertyString ("Type");
   pol = !strcmp (type, "pfet") ? -1 : 1;
 
   // calculate effective channel length
@@ -279,7 +279,7 @@ void mosfet::initModel (void) {
     nr_double_t Nss = getPropertyDouble ("Nss");
     nr_double_t PhiMS, PhiG, Eg;
     // bandgap for silicon
-    Eg = Egap (kelvin (T));
+    Eg = Egap (celsius2kelvin (T));
     if (Tpg != 0.0) { // n-poly or p-poly
       PhiG = 4.15 + Eg / 2 - pol * Tpg * Eg / 2;
     } else {          // alumina
@@ -387,7 +387,7 @@ void mosfet::calcDC (void) {
 
   nr_double_t Ut, IeqBS, IeqBD, IeqDS, UbsCrit, UbdCrit, gtiny;
 
-  T = kelvin (T);
+  T = celsius2kelvin (T);
   Ut = T * kBoverQ;
   Ugd = real (getV (NODE_G) - getV (NODE_D)) * pol;
   Ugs = real (getV (NODE_G) - getV (NODE_S)) * pol;
@@ -447,7 +447,7 @@ void mosfet::calcDC (void) {
   else {
     // taylor series of "sqrt (x - 1)" -> continual at Ubs/Ubd = 0
     Sarg = Sphi - Upn / Sphi / 2;
-    Sarg = MAX (Sarg, 0);
+    Sarg = std::max (Sarg, 0.0);
   }
 
   // calculate bias-dependent threshold voltage
@@ -480,7 +480,7 @@ void mosfet::calcDC (void) {
     }
     gmb = gm * arg;
   }
-  Udsat = pol * MAX (Utst, 0);
+  Udsat = pol * std::max (Utst, 0.0);
   Ids = MOSdir * Ids;
   Uon = pol * Uon;
 
