@@ -80,7 +80,7 @@ gperfapphash::hash (register const char *str, register unsigned int len)
       1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
       1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827
     };
-  register int hval = (int)len;
+  register unsigned int hval = len;
 
   switch (hval)
     {
@@ -1903,9 +1903,9 @@ gperfapphash::get (register const char *str, register unsigned int len)
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = hash (str, len);
+      unsigned int key = hash (str, len);
 
-      if (key <= MAX_HASH_VALUE && key >= 0)
+      if (key <= MAX_HASH_VALUE)
         {
           register const char *s = applist[key].key;
 
