@@ -49,7 +49,7 @@ sweep::sweep () : object () {
 }
 
 // Constructor creates a named instance of the sweep class.
-sweep::sweep (const char * n) : object (n) {
+sweep::sweep (const std::string &n) : object (n) {
   type = SWEEP_UNKNOWN;
   data = NULL;
   size = 0;
@@ -59,8 +59,8 @@ sweep::sweep (const char * n) : object (n) {
 
 // Destructor deletes the sweep class object.
 sweep::~sweep () {
-  if (data) free (data);
-  if (txt) free (txt);
+  free (data);
+  free (txt);
 }
 
 /* The copy constructor creates a new instance of the sweep class
@@ -108,7 +108,7 @@ void sweep::setSize (int points) {
 
 // The function creates a string representation of the sweep definition.
 char * sweep::toString (void) {
-  if (txt) free (txt);
+  free (txt);
   if (data == NULL || size == 0) return (char *) "";
   int len = 3 + size - 1;
   txt = (char *) malloc (len);
@@ -159,7 +159,7 @@ linsweep::linsweep () : sweep () {
 }
 
 // Constructor creates a named instance of the linsweep class.
-linsweep::linsweep (const char * n) : sweep (n) {
+linsweep::linsweep (const std::string &n) : sweep (n) {
   type = SWEEP_LINEAR;
 }
 
@@ -182,7 +182,7 @@ logsweep::logsweep () : sweep () {
 }
 
 // Constructor creates a named instance of the logsweep class.
-logsweep::logsweep (const char * n) : sweep (n) {
+logsweep::logsweep (const std::string &n) : sweep (n) {
   type = SWEEP_LOGARITHMIC;
 }
 
@@ -205,7 +205,7 @@ consweep::consweep () : sweep () {
 }
 
 // Constructor creates a named instance of the consweep class.
-consweep::consweep (const char * n) : sweep (n) {
+  consweep::consweep (const std::string &n) : sweep (n) {
   type = SWEEP_CONSTANT;
 }
 
@@ -226,7 +226,7 @@ lstsweep::lstsweep () : sweep () {
 }
 
 // Constructor creates a named instance of the lstsweep class.
-lstsweep::lstsweep (const char * n) : sweep (n) {
+lstsweep::lstsweep (const std::string& n) : sweep (n) {
   type = SWEEP_LIST;
 }
 
